pilas.actores.actor

Package pilas :: Package actores :: Module actor |
[hide private]
[frames] | no frames]

# Module actor

source code

Classes | [hide private]
| Actor Representa un objeto visible en pantalla, algo que se ve y tiene posicion.

Variables | [hide private]
| IZQUIERDA = ``[``'``izquierda``'``]``
| DERECHA = ``[``'``derecha``'``]``
| ARRIBA = ``[``'``arriba``'``,` `'``superior``'``]``
| CENTRO = ``[``'``centro``'``,` `'``centrado``'``,` `'``medio``'``,` `'``arriba``'``]``
| ABAJO = ``[``'``abajo``'``,` `'``inferior``'``,` `'``debajo``'``]``
| __package__ = ``'``pilas.actores``'``